# visbeat
Code for making anything dance to anything.
Based on "Visual Rhythm and Beat" SIGGRAPH 2018, Abe Davis and Maneesh Agrawala

Project Website: http://abedavis.com/visualbeat/


You can install using 
`pip install visbeat`

The easiest way to get started is probably to use the docker file. It will install everything and run a jupyter notebook for you in the examples folder. If you have trouble getting things to run on your own machine, the docker file may also provide guidance.
 